from beets.plugins import BeetsPlugin
import musicbrainzngs
import re

class LidarrFieldsPlugin(BeetsPlugin):
  def __init__(self):
    super(LidarrFieldsPlugin, self).__init__()
    
    self.mb_releasegroupid = None
    self.releasegroupartist = None
    self.mb_albumid = None
    self.lidarralbum = None
    
    self.template_fields['releasegroupartist'] = self._tmpl_releasegroupartist
    self.template_fields['lidarralbum'] = self._tmpl_lidarralbum

  def _tmpl_releasegroupartist(self, item):
    if item.singleton:
      return None
    
    if item.mb_releasegroupid != self.mb_releasegroupid:
      rel = musicbrainzngs.get_release_group_by_id(item.mb_releasegroupid, ['artist-credits'])
      self.releasegroupartist = rel['release-group']['artist-credit'][0]['artist']['name']
      self.mb_releasegroupid = item.mb_releasegroupid
    
    return self.releasegroupartist
  
  def _tmpl_lidarralbum(self, item):
    if item.mb_albumid != self.mb_albumid or item.singleton:
      rep = {'/': '+', ':': '-', '?': '!', '.' : ''}
      regexp = re.compile('|'.join(map(re.escape, rep)))
      self.lidarralbum = regexp.sub(lambda match: rep[match.group(0)], item.album)
      self.mb_albumid = item.mb_albumid
    
    return self.lidarralbum



#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Note: To use the 'upload' functionality of this file, you must:
#   $ pip install twine

import io
import os
import sys
from shutil import rmtree

from setuptools import find_packages, setup, Command

# Package meta-data.
NAME = 'beets-lidarr-fields'
DESCRIPTION = 'Beets plugin that defines some useful template fields to customize your path formats in a more lidarr (default) way.'
URL = 'https://github.com/rafaelparente/beets-lidarr-fields'
EMAIL = 'rafaelp.dev@gmail.com'
AUTHOR = 'Rafael Parente'
REQUIRES_PYTHON = '>=3.4.0'
VERSION = '1.0.4'

# What packages are required for this module to be executed?
REQUIRED = [
  'beets', 'musicbrainzngs',
  # 'requests', 'maya', 'records',
]

# What packages are optional?
EXTRAS = {
  # 'fancy feature': ['django'],
}

# The rest you shouldn't have to touch too much :)
# ------------------------------------------------
# Except, perhaps the License and Trove Classifiers!
# If you do change the License, remember to change the Trove Classifier for that!

here = os.path.abspath(os.path.dirname(__file__))

# Import the README and use it as the long-description.
# Note: this will only work if 'README.md' is present in your MANIFEST.in file!
try:
  with io.open(os.path.join(here, 'README.md'), encoding='utf-8') as f:
    long_description = '\n' + f.read()
except FileNotFoundError:
  long_description = DESCRIPTION

# Load the package's __version__.py module as a dictionary.
about = {}
if not VERSION:
  project_slug = NAME.lower().replace("-", "_").replace(" ", "_")
  with open(os.path.join(here, project_slug, '__version__.py')) as f:
    exec(f.read(), about)
else:
  about['__version__'] = VERSION


class UploadCommand(Command):
  """Support setup.py upload."""

  description = 'Build and publish the package.'
  user_options = []

  @staticmethod
  def status(s):
    """Prints things in bold."""
    print('\033[1m{0}\033[0m'.format(s))

  def initialize_options(self):
    pass

  def finalize_options(self):
    pass

  def run(self):
    try:
      self.status('Removing previous builds…')
      rmtree(os.path.join(here, 'dist'))
    except OSError:
      pass

    self.status('Building Source and Wheel (universal) distribution…')
    os.system('{0} setup.py sdist bdist_wheel --universal'.format(sys.executable))

    os.system('twine check dist/*')

    self.status('Uploading the package to PyPI via Twine…')
    os.system('twine upload dist/*')

    self.status('Pushing git tags…')
    os.system('git tag v{0}'.format(about['__version__']))
    os.system('git push --tags')
    
    sys.exit()


# Where the magic happens:
setup(
  name=NAME,
  version=about['__version__'],
  description=DESCRIPTION,
  long_description=long_description,
  long_description_content_type='text/markdown',
  author=AUTHOR,
  author_email=EMAIL,
  python_requires=REQUIRES_PYTHON,
  url=URL,
  packages=find_packages(exclude=["tests", "*.tests", "*.tests.*", "tests.*"]),
  # If your package is a single module, use this instead of 'packages':
  # py_modules=['mypackage'],

  # entry_points={
  #   'console_scripts': ['mycli=mymodule:cli'],
  # },
  install_requires=REQUIRED,
  extras_require=EXTRAS,
  include_package_data=True,
  license='MIT',
  classifiers=[
    # Trove classifiers
    # Full list: https://pypi.python.org/pypi?%3Aaction=list_classifiers
    'Development Status :: 5 - Production/Stable',
    'Environment :: Plugins',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python',
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: Implementation :: CPython',
    'Programming Language :: Python :: Implementation :: PyPy',
    'Topic :: Multimedia :: Sound/Audio'
  ],
  # $ setup.py publish support.
  cmdclass={
    'upload': UploadCommand,
  },
)